import React from 'react';
import FontAwesome from './modules/FontAwesome';
import { makeClasses } from './helpers/object';
export default function TableHeader({ tableHeaders, sortedProp, onSortChange, classes, components: { TableHead, TableRow, TableCell } }) {
    function onSortHandler(prop) {
        return () => onSortChange(prop);
    }
    const headings = [];
    for (let i = 0; i < tableHeaders.length; i += 1) {
        const thClass = makeClasses({
            'thead-th': true,
            sortable: tableHeaders[i].sortable === true
        });
        const thProps = {
            key: `th-${i}`,
            onClick: tableHeaders[i].sortable === true
                ? onSortHandler(tableHeaders[i].prop)
                : undefined,
            className: makeClasses(thClass, classes.theadCol)
        };
        let sortIcon = 'sort';
        let sortIconRender = null;
        if (tableHeaders[i].sortable === true) {
            if (sortedProp !== {} && sortedProp.prop === tableHeaders[i].prop) {
                if (sortedProp.isAscending) {
                    sortIcon = 'sort-asc';
                }
                else {
                    sortIcon = 'sort-desc';
                }
            }
            sortIconRender = React.createElement(FontAwesome, { icon: sortIcon, additionalClass: "fa-fw" });
        }
        const headerCell = tableHeaders[i].headerCell;
        let rendered;
        if (headerCell) {
            rendered = headerCell(sortIconRender, sortedProp);
        }
        else {
            rendered = (React.createElement(React.Fragment, null,
                tableHeaders[i].title,
                React.createElement("span", { className: "pull-right" }, sortIconRender)));
        }
        headings.push(React.createElement(TableCell, { ...thProps }, rendered));
    }
    return (React.createElement(TableHead, { className: makeClasses('thead', classes.thead) },
        React.createElement(TableRow, { className: makeClasses('thead-tr', classes.theadRow) }, headings)));
}
